summaryrefslogtreecommitdiff
path: root/tools/node_modules/eslint/lib/cli-engine
diff options
context:
space:
mode:
Diffstat (limited to 'tools/node_modules/eslint/lib/cli-engine')
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/cascading-config-array-factory.js51
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/cli-engine.js54
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/config-array-factory.js114
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/config-array/config-array.js13
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/config-array/extracted-config.js27
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/config-array/ignore-pattern.js231
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/config-array/index.js2
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/file-enumerator.js73
-rw-r--r--tools/node_modules/eslint/lib/cli-engine/ignored-paths.js363
9 files changed, 510 insertions, 418 deletions
diff --git a/tools/node_modules/eslint/lib/cli-engine/config-array-factory.js b/tools/node_modules/eslint/lib/cli-engine/config-array-factory.js
index cf529b6ee6..c444031bcb 100644
--- a/tools/node_modules/eslint/lib/cli-engine/config-array-factory.js
+++ b/tools/node_modules/eslint/lib/cli-engine/config-array-factory.js
@@ -17,6 +17,12 @@
* Create a `ConfigArray` instance from a config file which is on a given
* directory. This tries to load `.eslintrc.*` or `package.json`. If not
* found, returns an empty `ConfigArray`.
+ * - `loadESLintIgnore(filePath)`
+ * Create a `ConfigArray` instance from a config file that is `.eslintignore`
+ * format. This is to handle `--ignore-path` option.
+ * - `loadDefaultESLintIgnore()`
+ * Create a `ConfigArray` instance from `.eslintignore` or `package.json` in
+ * the current working directory.
*
* `ConfigArrayFactory` class has the responsibility that loads configuration
* files, including loading `extends`, `parser`, and `plugins`. The created
@@ -40,7 +46,12 @@ const stripComments = require("strip-json-comments");
const { validateConfigSchema } = require("../shared/config-validator");
const naming = require("../shared/naming");
const ModuleResolver = require("../shared/relative-module-resolver");
-const { ConfigArray, ConfigDependency, OverrideTester } = require("./config-array");
+const {
+ ConfigArray,
+ ConfigDependency,
+ IgnorePattern,
+ OverrideTester
+} = require("./config-array");
const debug = require("debug")("eslint:config-array-factory");
//------------------------------------------------------------------------------
@@ -222,6 +233,26 @@ function loadPackageJSONConfigFile(filePath) {
}
/**
+ * Loads a `.eslintignore` from a file.
+ * @param {string} filePath The filename to load.
+ * @returns {string[]} The ignore patterns from the file.
+ * @private
+ */
+function loadESLintIgnoreFile(filePath) {
+ debug(`Loading .eslintignore file: ${filePath}`);
+
+ try {
+ return readFile(filePath)
+ .split(/\r?\n/gu)
+ .filter(line => line.trim() !== "" && !line.startsWith("#"));
+ } catch (e) {
+ debug(`Error reading .eslintignore file: ${filePath}`);
+ e.message = `Cannot read .eslintignore file: ${filePath}\nError: ${e.message}`;
+ throw e;
+ }
+}
+
+/**
* Creates an error to notify about a missing config to extend from.
* @param {string} configName The name of the missing config.
* @param {string} importerName The name of the config that imported the missing config
@@ -404,6 +435,54 @@ class ConfigArrayFactory {
}
/**
+ * Load `.eslintignore` file.
+ * @param {string} filePath The path to a `.eslintignore` file to load.
+ * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
+ */
+ loadESLintIgnore(filePath) {
+ const { cwd } = internalSlotsMap.get(this);
+ const absolutePath = path.resolve(cwd, filePath);
+ const name = path.relative(cwd, absolutePath);
+ const ignorePatterns = loadESLintIgnoreFile(absolutePath);
+
+ return createConfigArray(
+ this._normalizeESLintIgnoreData(ignorePatterns, absolutePath, name)
+ );
+ }
+
+ /**
+ * Load `.eslintignore` file in the current working directory.
+ * @returns {ConfigArray} Loaded config. An empty `ConfigArray` if any config doesn't exist.
+ */
+ loadDefaultESLintIgnore() {
+ const { cwd } = internalSlotsMap.get(this);
+ const eslintIgnorePath = path.resolve(cwd, ".eslintignore");
+ const packageJsonPath = path.resolve(cwd, "package.json");
+
+ if (fs.existsSync(eslintIgnorePath)) {
+ return this.loadESLintIgnore(eslintIgnorePath);
+ }
+ if (fs.existsSync(packageJsonPath)) {
+ const data = loadJSONConfigFile(packageJsonPath);
+
+ if (Object.hasOwnProperty.call(data, "eslintIgnore")) {
+ if (!Array.isArray(data.eslintIgnore)) {
+ throw new Error("Package.json eslintIgnore property requires an array of paths");
+ }
+ return createConfigArray(
+ this._normalizeESLintIgnoreData(
+ data.eslintIgnore,
+ packageJsonPath,
+ "eslintIgnore in package.json"
+ )
+ );
+ }
+ }
+
+ return new ConfigArray();
+ }
+
+ /**
* Load a given config file.
* @param {string} filePath The path to a config file.
* @param {string} name The config name.
@@ -452,6 +531,30 @@ class ConfigArrayFactory {
}
/**
+ * Normalize a given `.eslintignore` data to config array elements.
+ * @param {string[]} ignorePatterns The patterns to ignore files.
+ * @param {string|undefined} filePath The file path of this config.
+ * @param {string|undefined} name The name of this config.
+ * @returns {IterableIterator<ConfigArrayElement>} The normalized config.
+ * @private
+ */
+ *_normalizeESLintIgnoreData(ignorePatterns, filePath, name) {
+ const elements = this._normalizeObjectConfigData(
+ { ignorePatterns },
+ filePath,
+ name
+ );
+
+ // Set `ignorePattern.loose` flag for backward compatibility.
+ for (const element of elements) {
+ if (element.ignorePattern) {
+ element.ignorePattern.loose = true;
+ }
+ yield element;
+ }
+ }
+
+ /**
* Normalize a given config to an array.
* @param {ConfigData} configData The config data to normalize.
* @param {string|undefined} providedFilePath The file path of this config.
@@ -494,6 +597,9 @@ class ConfigArrayFactory {
if (element.criteria) {
element.criteria.basePath = basePath;
}
+ if (element.ignorePattern) {
+ element.ignorePattern.basePath = basePath;
+ }
/*
* Merge the criteria; this is for only file extension processors in
@@ -526,6 +632,7 @@ class ConfigArrayFactory {
env,
extends: extend,
globals,
+ ignorePatterns,
noInlineConfig,
parser: parserName,
parserOptions,
@@ -541,6 +648,10 @@ class ConfigArrayFactory {
name
) {
const extendList = Array.isArray(extend) ? extend : [extend];
+ const ignorePattern = ignorePatterns && new IgnorePattern(
+ Array.isArray(ignorePatterns) ? ignorePatterns : [ignorePatterns],
+ filePath ? path.dirname(filePath) : internalSlotsMap.get(this).cwd
+ );
// Flatten `extends`.
for (const extendName of extendList.filter(Boolean)) {
@@ -569,6 +680,7 @@ class ConfigArrayFactory {
criteria: null,
env,
globals,
+ ignorePattern,
noInlineConfig,
parser,
parserOptions,
diff --git a/tools/node_modules/eslint/lib/cli-engine/config-array/config-array.js b/tools/node_modules/eslint/lib/cli-engine/config-array/config-array.js
index 089ff305a2..4fae8deaca 100644
--- a/tools/node_modules/eslint/lib/cli-engine/config-array/config-array.js
+++ b/tools/node_modules/eslint/lib/cli-engine/config-array/config-array.js
@@ -31,6 +31,7 @@
//------------------------------------------------------------------------------
const { ExtractedConfig } = require("./extracted-config");
+const { IgnorePattern } = require("./ignore-pattern");
//------------------------------------------------------------------------------
// Helpers
@@ -54,6 +55,7 @@ const { ExtractedConfig } = require("./extracted-config");
* @property {InstanceType<OverrideTester>|null} criteria The tester for the `files` and `excludedFiles` of this config element.
* @property {Record<string, boolean>|undefined} env The environment settings.
* @property {Record<string, GlobalConf>|undefined} globals The global variable settings.
+ * @property {IgnorePattern|undefined} ignorePattern The ignore patterns.
* @property {boolean|undefined} noInlineConfig The flag that disables directive comments.
* @property {DependentParser|undefined} parser The parser loader.
* @property {Object|undefined} parserOptions The parser options.
@@ -231,6 +233,7 @@ function mergeRuleConfigs(target, source) {
*/
function createConfig(instance, indices) {
const config = new ExtractedConfig();
+ const ignorePatterns = [];
// Merge elements.
for (const index of indices) {
@@ -260,6 +263,11 @@ function createConfig(instance, indices) {
config.reportUnusedDisableDirectives = element.reportUnusedDisableDirectives;
}
+ // Collect ignorePatterns
+ if (element.ignorePattern) {
+ ignorePatterns.push(element.ignorePattern);
+ }
+
// Merge others.
mergeWithoutOverwrite(config.env, element.env);
mergeWithoutOverwrite(config.globals, element.globals);
@@ -269,6 +277,11 @@ function createConfig(instance, indices) {
mergeRuleConfigs(config.rules, element.rules);
}
+ // Create the predicate function for ignore patterns.
+ if (ignorePatterns.length > 0) {
+ config.ignores = IgnorePattern.createIgnore(ignorePatterns.reverse());
+ }
+
return config;
}
diff --git a/tools/node_modules/eslint/lib/cli-engine/config-array/extracted-config.js b/tools/node_modules/eslint/lib/cli-engine/config-array/extracted-config.js
index 66858313ba..b27d6ffb18 100644
--- a/tools/node_modules/eslint/lib/cli-engine/config-array/extracted-config.js
+++ b/tools/node_modules/eslint/lib/cli-engine/config-array/extracted-config.js
@@ -16,6 +16,8 @@
*/
"use strict";
+const { IgnorePattern } = require("./ignore-pattern");
+
// For VSCode intellisense
/** @typedef {import("../../shared/types").ConfigData} ConfigData */
/** @typedef {import("../../shared/types").GlobalConf} GlobalConf */
@@ -24,6 +26,17 @@
/** @typedef {import("./config-dependency").DependentPlugin} DependentPlugin */
/**
+ * Check if `xs` starts with `ys`.
+ * @template T
+ * @param {T[]} xs The array to check.
+ * @param {T[]} ys The array that may be the first part of `xs`.
+ * @returns {boolean} `true` if `xs` starts with `ys`.
+ */
+function startsWith(xs, ys) {
+ return xs.length >= ys.length && ys.every((y, i) => y === xs[i]);
+}
+
+/**
* The class for extracted config data.
*/
class ExtractedConfig {
@@ -48,6 +61,12 @@ class ExtractedConfig {
this.globals = {};
/**
+ * The glob patterns that ignore to lint.
+ * @type {(((filePath:string, dot?:boolean) => boolean) & { basePath:string; patterns:string[] }) | undefined}
+ */
+ this.ignores = void 0;
+
+ /**
* The flag that disables directive comments.
* @type {boolean|undefined}
*/
@@ -106,11 +125,19 @@ class ExtractedConfig {
configNameOfNoInlineConfig: _ignore1,
processor: _ignore2,
/* eslint-enable no-unused-vars */
+ ignores,
...config
} = this;
config.parser = config.parser && config.parser.filePath;
config.plugins = Object.keys(config.plugins).filter(Boolean).reverse();
+ config.ignorePatterns = ignores ? ignores.patterns : [];
+
+ // Strip the default patterns from `ignorePatterns`.
+ if (startsWith(config.ignorePatterns, IgnorePattern.DefaultPatterns)) {
+ config.ignorePatterns =
+ config.ignorePatterns.slice(IgnorePattern.DefaultPatterns.length);
+ }
return config;
}
diff --git a/tools/node_modules/eslint/lib/cli-engine/config-array/ignore-pattern.js b/tools/node_modules/eslint/lib/cli-engine/config-array/ignore-pattern.js
new file mode 100644
index 0000000000..6140194433
--- /dev/null
+++ b/tools/node_modules/eslint/lib/cli-engine/config-array/ignore-pattern.js
@@ -0,0 +1,231 @@
+/**
+ * @fileoverview `IgnorePattern` class.
+ *
+ * `IgnorePattern` class has the set of glob patterns and the base path.
+ *
+ * It provides two static methods.
+ *
+ * - `IgnorePattern.createDefaultIgnore(cwd)`
+ * Create the default predicate function.
+ * - `IgnorePattern.createIgnore(ignorePatterns)`
+ * Create the predicate function from multiple `IgnorePattern` objects.
+ *
+ * It provides two properties and a method.
+ *
+ * - `patterns`
+ * The glob patterns that ignore to lint.
+ * - `basePath`
+ * The base path of the glob patterns. If absolute paths existed in the
+ * glob patterns, those are handled as relative paths to the base path.
+ * - `getPatternsRelativeTo(basePath)`
+ * Get `patterns` as modified for a given base path. It modifies the
+ * absolute paths in the patterns as prepending the difference of two base
+ * paths.
+ *
+ * `ConfigArrayFactory` creates `IgnorePattern` objects when it processes
+ * `ignorePatterns` properties.
+ *
+ * @author Toru Nagashima <https://github.com/mysticatea>
+ */
+"use strict";
+
+//------------------------------------------------------------------------------
+// Requirements
+//------------------------------------------------------------------------------
+
+const assert = require("assert");
+const path = require("path");
+const ignore = require("ignore");
+const debug = require("debug")("eslint:ignore-pattern");
+
+/** @typedef {ReturnType<import("ignore").default>} Ignore */
+
+//------------------------------------------------------------------------------
+// Helpers
+//------------------------------------------------------------------------------
+
+/**
+ * Get the path to the common ancestor directory of given paths.
+ * @param {string[]} sourcePaths The paths to calculate the common ancestor.
+ * @returns {string} The path to the common ancestor directory.
+ */
+function getCommonAncestorPath(sourcePaths) {
+ let result = sourcePaths[0];
+
+ for (let i = 1; i < sourcePaths.length; ++i) {
+ const a = result;
+ const b = sourcePaths[i];
+
+ // Set the shorter one (it's the common ancestor if one includes the other).
+ result = a.length < b.length ? a : b;
+
+ // Set the common ancestor.
+ for (let j = 0, lastSepPos = 0; j < a.length && j < b.length; ++j) {
+ if (a[j] !== b[j]) {
+ result = a.slice(0, lastSepPos);
+ break;
+ }
+ if (a[j] === path.sep) {
+ lastSepPos = j;
+ }
+ }
+ }
+
+ return result || path.sep;
+}
+
+/**
+ * Make relative path.
+ * @param {string} from The source path to get relative path.
+ * @param {string} to The destination path to get relative path.
+ * @returns {string} The relative path.
+ */
+function relative(from, to) {
+ const relPath = path.relative(from, to);
+
+ if (path.sep === "/") {
+ return relPath;
+ }
+ return relPath.split(path.sep).join("/");
+}
+
+/**
+ * Get the trailing slash if existed.
+ * @param {string} filePath The path to check.
+ * @returns {string} The trailing slash if existed.
+ */
+function dirSuffix(filePath) {
+ const isDir = (
+ filePath.endsWith(path.sep) ||
+ (process.platform === "win32" && filePath.endsWith("/"))
+ );
+
+ return isDir ? "/" : "";
+}
+
+const DefaultPatterns = Object.freeze(["/node_modules/*", "/bower_components/*"]);
+const DotPatterns = Object.freeze([".*", "!../"]);
+
+//------------------------------------------------------------------------------
+// Public
+//------------------------------------------------------------------------------
+
+class IgnorePattern {
+
+ /**
+ * The default patterns.
+ * @type {string[]}
+ */
+ static get DefaultPatterns() {
+ return DefaultPatterns;
+ }
+
+ /**
+ * Create the default predicate function.
+ * @param {string} cwd The current working directory.
+ * @returns {((filePath:string, dot:boolean) => boolean) & {basePath:string; patterns:string[]}}
+ * The preficate function.
+ * The first argument is an absolute path that is checked.
+ * The second argument is the flag to not ignore dotfiles.
+ * If the predicate function returned `true`, it means the path should be ignored.
+ */
+ static createDefaultIgnore(cwd) {
+ return this.createIgnore([new IgnorePattern(DefaultPatterns, cwd)]);
+ }
+
+ /**
+ * Create the predicate function from multiple `IgnorePattern` objects.
+ * @param {IgnorePattern[]} ignorePatterns The list of ignore patterns.
+ * @returns {((filePath:string, dot?:boolean) => boolean) & {basePath:string; patterns:string[]}}
+ * The preficate function.
+ * The first argument is an absolute path that is checked.
+ * The second argument is the flag to not ignore dotfiles.
+ * If the predicate function returned `true`, it means the path should be ignored.
+ */
+ static createIgnore(ignorePatterns) {
+ debug("Create with: %o", ignorePatterns);
+
+ const basePath = getCommonAncestorPath(ignorePatterns.map(p => p.basePath));
+ const patterns = [].concat(
+ ...ignorePatterns.map(p => p.getPatternsRelativeTo(basePath))
+ );
+ const ig = ignore().add([...DotPatterns, ...patterns]);
+ const dotIg = ignore().add(patterns);
+
+ debug(" processed: %o", { basePath, patterns });
+
+ return Object.assign(
+ (filePath, dot = false) => {
+ assert(path.isAbsolute(filePath), "'filePath' should be an absolute path.");
+ const relPathRaw = relative(basePath, filePath);
+ const relPath = relPathRaw && (relPathRaw + dirSuffix(filePath));
+ const adoptedIg = dot ? dotIg : ig;
+ const result = relPath !== "" && adoptedIg.ignores(relPath);
+
+ debug("Check", { filePath, dot, relativePath: relPath, result });
+ return result;
+ },
+ { basePath, patterns }
+ );
+ }
+
+ /**
+ * Initialize a new `IgnorePattern` instance.
+ * @param {string[]} patterns The glob patterns that ignore to lint.
+ * @param {string} basePath The base path of `patterns`.
+ */
+ constructor(patterns, basePath) {
+ assert(path.isAbsolute(basePath), "'basePath' should be an absolute path.");
+
+ /**
+ * The glob patterns that ignore to lint.
+ * @type {string[]}
+ */
+ this.patterns = patterns;
+
+ /**
+ * The base path of `patterns`.
+ * @type {string}
+ */
+ this.basePath = basePath;
+
+ /**
+ * If `true` then patterns which don't start with `/` will match the paths to the outside of `basePath`. Defaults to `false`.
+ *
+ * It's set `true` for `.eslintignore`, `package.json`, and `--ignore-path` for backward compatibility.
+ * It's `false` as-is for `ignorePatterns` property in config files.
+ * @type {boolean}
+ */
+ this.loose = false;
+ }
+
+ /**
+ * Get `patterns` as modified for a given base path. It modifies the
+ * absolute paths in the patterns as prepending the difference of two base
+ * paths.
+ * @param {string} newBasePath The base path.
+ * @returns {string[]} Modifired patterns.
+ */
+ getPatternsRelativeTo(newBasePath) {
+ assert(path.isAbsolute(newBasePath), "'newBasePath' should be an absolute path.");
+ const { basePath, loose, patterns } = this;
+
+ if (newBasePath === basePath) {
+ return patterns;
+ }
+ const prefix = `/${relative(newBasePath, basePath)}`;
+
+ return patterns.map(pattern => {
+ const negative = pattern.startsWith("!");
+ const head = negative ? "!" : "";
+ const body = negative ? pattern.slice(1) : pattern;
+
+ if (body.startsWith("/") || body.startsWith("../")) {
+ return `${head}${prefix}${body}`;
+ }
+ return loose ? pattern : `${head}${prefix}/**/${body}`;
+ });
+ }
+}
+
+module.exports = { IgnorePattern };
diff --git a/tools/node_modules/eslint/lib/cli-engine/config-array/index.js b/tools/node_modules/eslint/lib/cli-engine/config-array/index.js
index de8831906f..928d76c83a 100644
--- a/tools/node_modules/eslint/lib/cli-engine/config-array/index.js
+++ b/tools/node_modules/eslint/lib/cli-engine/config-array/index.js
@@ -7,12 +7,14 @@
const { ConfigArray, getUsedExtractedConfigs } = require("./config-array");
const { ConfigDependency } = require("./config-dependency");
const { ExtractedConfig } = require("./extracted-config");
+const { IgnorePattern } = require("./ignore-pattern");
const { OverrideTester } = require("./override-tester");
module.exports = {
ConfigArray,
ConfigDependency,
ExtractedConfig,
+ IgnorePattern,
OverrideTester,
getUsedExtractedConfigs
};
diff --git a/tools/node_modules/eslint/lib/cli-engine/file-enumerator.js b/tools/node_modules/eslint/lib/cli-engine/file-enumerator.js
index 38f55de039..700f8009cf 100644
--- a/tools/node_modules/eslint/lib/cli-engine/file-enumerator.js
+++ b/tools/node_modules/eslint/lib/cli-engine/file-enumerator.js
@@ -40,8 +40,8 @@ const getGlobParent = require("glob-parent");
const isGlob = require("is-glob");
const { escapeRegExp } = require("lodash");
const { Minimatch } = require("minimatch");
+const { IgnorePattern } = require("./config-array");
const { CascadingConfigArrayFactory } = require("./cascading-config-array-factory");
-const { IgnoredPaths } = require("./ignored-paths");
const debug = require("debug")("eslint:file-enumerator");
//------------------------------------------------------------------------------
@@ -64,7 +64,6 @@ const IGNORED = 2;
* @property {string[]} [extensions] The extensions to match files for directory patterns.
* @property {boolean} [globInputPaths] Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
* @property {boolean} [ignore] The flag to check ignored files.
- * @property {IgnoredPaths} [ignoredPaths] The ignored paths.
* @property {string[]} [rulePaths] The value of `--rulesdir` option.
*/
@@ -92,8 +91,7 @@ const IGNORED = 2;
* @property {RegExp} extensionRegExp The RegExp to test if a string ends with specific file extensions.
* @property {boolean} globInputPaths Set to false to skip glob resolution of input file paths to lint (default: true). If false, each input file paths is assumed to be a non-glob path to an existing file.
* @property {boolean} ignoreFlag The flag to check ignored files.
- * @property {IgnoredPaths} ignoredPathsWithDotfiles The ignored paths but don't include dot files.
- * @property {IgnoredPaths} ignoredPaths The ignored paths.
+ * @property {(filePath:string, dot:boolean) => boolean} defaultIgnores The default predicate function to ignore files.
*/
/** @type {WeakMap<FileEnumerator, FileEnumeratorInternalSlots>} */
@@ -192,12 +190,12 @@ class FileEnumerator {
configArrayFactory = new CascadingConfigArrayFactory({ cwd }),
extensions = [".js"],
globInputPaths = true,
- ignore = true,
- ignoredPaths = new IgnoredPaths({ cwd, ignore })
+ ignore = true
} = {}) {
internalSlotsMap.set(this, {
configArrayFactory,
cwd,
+ defaultIgnores: IgnorePattern.createDefaultIgnore(cwd),
extensionRegExp: new RegExp(
`.\\.(?:${extensions
.map(ext => escapeRegExp(
@@ -210,12 +208,7 @@ class FileEnumerator {
"u"
),
globInputPaths,
- ignoreFlag: ignore,
- ignoredPaths,
- ignoredPathsWithDotfiles: new IgnoredPaths({
- ...ignoredPaths.options,
- dotfiles: true
- })
+ ignoreFlag: ignore
});
}
@@ -321,7 +314,7 @@ class FileEnumerator {
const { configArrayFactory } = internalSlotsMap.get(this);
const config = configArrayFactory.getConfigArrayForFile(filePath);
- const ignored = this._isIgnoredFile(filePath, { direct: true });
+ const ignored = this._isIgnoredFile(filePath, { config, direct: true });
const flag = ignored ? IGNORED : NONE;
return [{ config, filePath, flag }];
@@ -353,7 +346,7 @@ class FileEnumerator {
_iterateFilesWithGlob(pattern, dotfiles) {
debug(`Glob: ${pattern}`);
- const directoryPath = getGlobParent(pattern);
+ const directoryPath = path.resolve(getGlobParent(pattern));
const globPart = pattern.slice(directoryPath.length + 1);
/*
@@ -399,9 +392,18 @@ class FileEnumerator {
// Check if the file is matched.
if (stat && stat.isFile()) {
if (!config) {
- config = configArrayFactory.getConfigArrayForFile(filePath);
+ config = configArrayFactory.getConfigArrayForFile(
+ filePath,
+
+ /*
+ * We must ignore `ConfigurationNotFoundError` at this
+ * point because we don't know if target files exist in
+ * this directory.
+ */
+ { ignoreNotFoundError: true }
+ );
}
- const ignored = this._isIgnoredFile(filePath, options);
+ const ignored = this._isIgnoredFile(filePath, { ...options, config });
const flag = ignored ? IGNORED_SILENTLY : NONE;
const matched = options.selector
@@ -413,7 +415,11 @@ class FileEnumerator {
if (matched) {
debug(`Yield: ${filename}${ignored ? " but ignored" : ""}`);
- yield { config, filePath, flag };
+ yield {
+ config: configArrayFactory.getConfigArrayForFile(filePath),
+ filePath,
+ flag
+ };
} else {
debug(`Didn't match: ${filename}`);
}
@@ -431,24 +437,37 @@ class FileEnumerator {
* Check if a given file should be ignored.
* @param {string} filePath The path to a file to check.
* @param {Object} options Options
+ * @param {ConfigArray} [options.config] The config for this file.
* @param {boolean} [options.dotfiles] If `true` then this is not ignore dot files by default.
* @param {boolean} [options.direct] If `true` then this is a direct specified file.
* @returns {boolean} `true` if the file should be ignored.
* @private
*/
- _isIgnoredFile(filePath, { dotfiles = false, direct = false }) {
+ _isIgnoredFile(filePath, {
+ config: providedConfig,
+ dotfiles = false,
+ direct = false
+ }) {
const {
- ignoreFlag,
- ignoredPaths,
- ignoredPathsWithDotfiles
+ configArrayFactory,
+ defaultIgnores,
+ ignoreFlag
} = internalSlotsMap.get(this);
- const adoptedIgnoredPaths = dotfiles
- ? ignoredPathsWithDotfiles
- : ignoredPaths;
- return ignoreFlag
- ? adoptedIgnoredPaths.contains(filePath)
- : (!direct && adoptedIgnoredPaths.contains(filePath, "default"));
+ if (ignoreFlag) {
+ const config =
+ providedConfig ||
+ configArrayFactory.getConfigArrayForFile(
+ filePath,
+ { ignoreNotFoundError: true }
+ );
+ const ignores =
+ config.extractConfig(filePath).ignores || defaultIgnores;
+
+ return ignores(filePath, dotfiles);
+ }
+
+ return !direct && defaultIgnores(filePath, dotfiles);
}
}
diff --git a/tools/node_modules/eslint/lib/cli-engine/ignored-paths.js b/tools/node_modules/eslint/lib/cli-engine/ignored-paths.js
deleted file mode 100644
index dec8e18604..0000000000
--- a/tools/node_modules/eslint/lib/cli-engine/ignored-paths.js
+++ /dev/null
@@ -1,363 +0,0 @@
-/**
- * @fileoverview Responsible for loading ignore config files and managing ignore patterns
- * @author Jonathan Rajavuori
- */
-
-"use strict";
-
-//------------------------------------------------------------------------------
-// Requirements
-//------------------------------------------------------------------------------
-
-const fs = require("fs"),
- path = require("path"),
- ignore = require("ignore");
-
-const debug = require("debug")("eslint:ignored-paths");
-
-//------------------------------------------------------------------------------
-// Constants
-//------------------------------------------------------------------------------
-
-const ESLINT_IGNORE_FILENAME = ".eslintignore";
-
-/**
- * Adds `"*"` at the end of `"node_modules/"`,
- * so that subtle directories could be re-included by .gitignore patterns
- * such as `"!node_modules/should_not_ignored"`
- */
-const DEFAULT_IGNORE_DIRS = [
- "/node_modules/*",
- "/bower_components/*"
-];
-const DEFAULT_OPTIONS = {
- dotfiles: false,
- cwd: process.cwd()
-};
-
-//------------------------------------------------------------------------------
-// Helpers
-//------------------------------------------------------------------------------
-
-/**
- * Find a file in the current directory.
- * @param {string} cwd Current working directory
- * @param {string} name File name
- * @returns {string} Path of ignore file or an empty string.
- */
-function findFile(cwd, name) {
- const ignoreFilePath = path.resolve(cwd, name);
-
- return fs.existsSync(ignoreFilePath) && fs.statSync(ignoreFilePath).isFile() ? ignoreFilePath : "";
-}
-
-/**
- * Find an ignore file in the current directory.
- * @param {string} cwd Current working directory
- * @returns {string} Path of ignore file or an empty string.
- */
-function findIgnoreFile(cwd) {
- return findFile(cwd, ESLINT_IGNORE_FILENAME);
-}
-
-/**
- * Find an package.json file in the current directory.
- * @param {string} cwd Current working directory
- * @returns {string} Path of package.json file or an empty string.
- */
-function findPackageJSONFile(cwd) {
- return findFile(cwd, "package.json");
-}
-
-/**
- * Merge options with defaults
- * @param {Object} options Options to merge with DEFAULT_OPTIONS constant
- * @returns {Object} Merged options
- */
-function mergeDefaultOptions(options) {
- return Object.assign({}, DEFAULT_OPTIONS, options);
-}
-
-/* eslint-disable jsdoc/check-param-names, jsdoc/require-param */
-/**
- * Normalize the path separators in a given string.
- * On Windows environment, this replaces `\` by `/`.
- * Otherwrise, this does nothing.
- * @param {string} str The path string to normalize.
- * @returns {string} The normalized path.
- */
-const normalizePathSeps = path.sep === "/"
- ? (str => str)
- : ((seps, str) => str.replace(seps, "/")).bind(null, new RegExp(`\\${path.sep}`, "gu"));
-/* eslint-enable jsdoc/check-param-names, jsdoc/require-param */
-
-/**
- * Converts a glob pattern to a new glob pattern relative to a different directory
- * @param {string} globPattern The glob pattern, relative the the old base directory
- * @param {string} relativePathToOldBaseDir A relative path from the new base directory to the old one
- * @returns {string} A glob pattern relative to the new base directory
- */
-function relativize(globPattern, relativePathToOldBaseDir) {
- if (relativePathToOldBaseDir === "") {
- return globPattern;
- }
-
- const prefix = globPattern.startsWith("!") ? "!" : "";
- const globWithoutPrefix = globPattern.replace(/^!/u, "");
-
- if (globWithoutPrefix.startsWith("/")) {
- return `${prefix}/${normalizePathSeps(relativePathToOldBaseDir)}${globWithoutPrefix}`;
- }
-
- return globPattern;
-}
-
-//------------------------------------------------------------------------------
-// Public Interface
-//------------------------------------------------------------------------------
-
-/**
- * IgnoredPaths class
- */
-class IgnoredPaths {
-
- // eslint-disable-next-line jsdoc/require-description
- /**
- * @param {Object} providedOptions object containing 'ignore', 'ignorePath' and 'patterns' properties
- */
- constructor(providedOptions) {
- const options = mergeDefaultOptions(providedOptions);
-
- this.cache = {};
-
- this.defaultPatterns = [].concat(DEFAULT_IGNORE_DIRS, options.patterns || []);
-
- this.ignoreFileDir = options.ignore !== false && options.ignorePath
- ? path.dirname(path.resolve(options.cwd, options.ignorePath))
- : options.cwd;
- this.options = options;
- this._baseDir = null;
-
- this.ig = {
- custom: ignore(),
- default: ignore()
- };
-
- this.defaultPatterns.forEach(pattern => this.addPatternRelativeToCwd(this.ig.default, pattern));
- if (options.dotfiles !== true) {
-
- /*
- * ignore files beginning with a dot, but not files in a parent or
- * ancestor directory (which in relative format will begin with `../`).
- */
- this.addPatternRelativeToCwd(this.ig.default, ".*");
- this.addPatternRelativeToCwd(this.ig.default, "!../");
- }
-
- /*
- * Add a way to keep track of ignored files. This was present in node-ignore
- * 2.x, but dropped for now as of 3.0.10.
- */
- this.ig.custom.ignoreFiles = [];
- this.ig.default.ignoreFiles = [];
-
- if (options.ignore !== false) {
- let ignorePath;
-
- if (options.ignorePath) {
- debug("Using specific ignore file");
-
- try {
- const stat = fs.statSync(options.ignorePath);
-
- if (!stat.isFile()) {
- throw new Error(`${options.ignorePath} is not a file`);
- }
- ignorePath = options.ignorePath;
- } catch (e) {
- e.message = `Cannot read ignore file: ${options.ignorePath}\nError: ${e.message}`;
- throw e;
- }
- } else {
- debug(`Looking for ignore file in ${options.cwd}`);
- ignorePath = findIgnoreFile(options.cwd);
-
- try {
- fs.statSync(ignorePath);
- debug(`Loaded ignore file ${ignorePath}`);
- } catch (e) {
- debug("Could not find ignore file in cwd");
- }
- }
-
- if (ignorePath) {
- debug(`Adding ${ignorePath}`);
- this.addIgnoreFile(this.ig.custom, ignorePath);
- this.addIgnoreFile(this.ig.default, ignorePath);
- } else {
- try {
-
- // if the ignoreFile does not exist, check package.json for eslintIgnore
- const packageJSONPath = findPackageJSONFile(options.cwd);
-
- if (packageJSONPath) {
- let packageJSONOptions;
-
- try {
- packageJSONOptions = JSON.parse(fs.readFileSync(packageJSONPath, "utf8"));
- } catch (e) {
- debug("Could not read package.json file to check eslintIgnore property");
- e.messageTemplate = "failed-to-read-json";
- e.messageData = {
- path: packageJSONPath,
- message: e.message
- };
- throw e;
- }
-
- if (packageJSONOptions.eslintIgnore) {
- if (Array.isArray(packageJSONOptions.eslintIgnore)) {
- packageJSONOptions.eslintIgnore.forEach(pattern => {
- this.addPatternRelativeToIgnoreFile(this.ig.custom, pattern);
- this.addPatternRelativeToIgnoreFile(this.ig.default, pattern);
- });
- } else {
- throw new TypeError("Package.json eslintIgnore property requires an array of paths");
- }
- }
- }
- } catch (e) {
- debug("Could not find package.json to check eslintIgnore property");
- throw e;
- }
- }
-
- if (options.ignorePattern) {
- this.addPatternRelativeToCwd(this.ig.custom, options.ignorePattern);
- this.addPatternRelativeToCwd(this.ig.default, options.ignorePattern);
- }
- }
- }
-
- /*
- * If `ignoreFileDir` is a subdirectory of `cwd`, all paths will be normalized to be relative to `cwd`.
- * Otherwise, all paths will be normalized to be relative to `ignoreFileDir`.
- * This ensures that the final normalized ignore rule will not contain `..`, which is forbidden in
- * ignore rules.
- */
-
- addPatternRelativeToCwd(ig, pattern) {
- const baseDir = this.getBaseDir();
- const cookedPattern = baseDir === this.options.cwd
- ? pattern
- : relativize(pattern, path.relative(baseDir, this.options.cwd));
-
- ig.addPattern(cookedPattern);
- debug("addPatternRelativeToCwd:\n original = %j\n cooked = %j", pattern, cookedPattern);
- }
-
- addPatternRelativeToIgnoreFile(ig, pattern) {
- const baseDir = this.getBaseDir();
- const cookedPattern = baseDir === this.ignoreFileDir
- ? pattern
- : relativize(pattern, path.relative(baseDir, this.ignoreFileDir));
-
- ig.addPattern(cookedPattern);
- debug("addPatternRelativeToIgnoreFile:\n original = %j\n cooked = %j", pattern, cookedPattern);
- }
-
- // Detect the common ancestor
- getBaseDir() {
- if (!this._baseDir) {
- const a = path.resolve(this.options.cwd);
- const b = path.resolve(this.ignoreFileDir);
- let lastSepPos = 0;
-
- // Set the shorter one (it's the common ancestor if one includes the other).
- this._baseDir = a.length < b.length ? a : b;
-
- // Set the common ancestor.
- for (let i = 0; i < a.length && i < b.length; ++i) {
- if (a[i] !== b[i]) {
- this._baseDir = a.slice(0, lastSepPos);
- break;
- }
- if (a[i] === path.sep) {
- lastSepPos = i;
- }
- }
-
- // If it's only Windows drive letter, it needs \
- if (/^[A-Z]:$/u.test(this._baseDir)) {
- this._baseDir += "\\";
- }
-
- debug("baseDir = %j", this._baseDir);
- }
- return this._baseDir;
- }
-
- /**
- * read ignore filepath
- * @param {string} filePath file to add to ig
- * @returns {Array} raw ignore rules
- */
- readIgnoreFile(filePath) {
- if (typeof this.cache[filePath] === "undefined") {
- this.cache[filePath] = fs.readFileSync(filePath, "utf8").split(/\r?\n/gu).filter(Boolean);
- }
- return this.cache[filePath];
- }
-
- /**
- * add ignore file to node-ignore instance
- * @param {Object} ig instance of node-ignore
- * @param {string} filePath file to add to ig
- * @returns {void}
- */
- addIgnoreFile(ig, filePath) {
- ig.ignoreFiles.push(filePath);
- this
- .readIgnoreFile(filePath)
- .forEach(ignoreRule => this.addPatternRelativeToIgnoreFile(ig, ignoreRule));
- }
-
- /**
- * Determine whether a file path is included in the default or custom ignore patterns
- * @param {string} filepath Path to check
- * @param {string} [category=undefined] check 'default', 'custom' or both (undefined)
- * @returns {boolean} true if the file path matches one or more patterns, false otherwise
- */
- contains(filepath, category) {
- const isDir = filepath.endsWith(path.sep) ||
- (path.sep === "\\" && filepath.endsWith("/"));
- let result = false;
- const basePath = this.getBaseDir();
- const absolutePath = path.resolve(this.options.cwd, filepath);
- let relativePath = path.relative(basePath, absolutePath);
-
- if (relativePath) {
- if (isDir) {
- relativePath += path.sep;
- }
- if (typeof category === "undefined") {
- result =
- (this.ig.default.filter([relativePath]).length === 0) ||
- (this.ig.custom.filter([relativePath]).length === 0);
- } else {
- result =
- (this.ig[category].filter([relativePath]).length === 0);
- }
- }
- debug("contains:");
- debug(" target = %j", filepath);
- debug(" base = %j", basePath);
- debug(" relative = %j", relativePath);
- debug(" result = %j", result);
-
- return result;
-
- }
-}
-
-module.exports = { IgnoredPaths };
diff --git a/tools/node_modules/eslint/lib/cli-engine/cascading-config-array-factory.js b/tools/node_modules/eslint/lib/cli-engine/cascading-config-array-factory.js
index 6c914ea491..52703a873b 100644
--- a/tools/node_modules/eslint/lib/cli-engine/cascading-config-array-factory.js
+++ b/tools/node_modules/eslint/lib/cli-engine/cascading-config-array-factory.js
@@ -27,7 +27,7 @@ const os = require("os");
const path = require("path");
const { validateConfigArray } = require("../shared/config-validator");
const { ConfigArrayFactory } = require("./config-array-factory");
-const { ConfigArray, ConfigDependency } = require("./config-array");
+const { ConfigArray, ConfigDependency, IgnorePattern } = require("./config-array");
const loadRules = require("./load-rules");
const debug = require("debug")("eslint:cascading-config-array-factory");
@@ -45,8 +45,9 @@ const debug = require("debug")("eslint:cascading-config-array-factory");
* @typedef {Object} CascadingConfigArrayFactoryOptions
* @property {Map<string,Plugin>} [additionalPluginPool] The map for additional plugins.
* @property {ConfigData} [baseConfig] The config by `baseConfig` option.
* @property {ConfigData} [cliConfig] The config by CLI options (`--env`, `--global`, `--parser`, `--parser-options`, `--plugin`, and `--rule`). CLI options overwrite the setting in config files.
* @property {string} [cwd] The base directory to start lookup.
+ * @property {string} [ignorePath] The path to the alternative file of `.eslintignore`.
* @property {string[]} [rulePaths] The value of `--rulesdir` option.
* @property {string} [specificConfigPath] The value of `--config` option.
* @property {boolean} [useEslintrc] if `false` then it doesn't load config files.
@@ -62,6 +63,7 @@ const debug = require("debug")("eslint:cascading-config-array-factory");
* @property {Map<string, ConfigArray>} configCache The cache from directory paths to config arrays.
* @property {string} cwd The base directory to start lookup.
* @property {WeakMap<ConfigArray, ConfigArray>} finalizeCache The cache from config arrays to finalized config arrays.
+ * @property {string} [ignorePath] The path to the alternative file of `.eslintignore`.
* @property {string[]|null} rulePaths The value of `--rulesdir` option. This is used to reset `baseConfigArray`.
* @property {string|null} specificConfigPath The value of `--config` option. This is used to reset `cliConfigArray`.
* @property {boolean} useEslintrc if `false` then it doesn't load config files.
@@ -86,14 +88,22 @@ function createBaseConfigArray({
{ name: "BaseConfig" }
);
+ /*
+ * Create the config array element for the default ignore patterns.
+ * This element has `ignorePattern` property that ignores the default
+ * patterns in the current working directory.
+ */
+ baseConfigArray.unshift(configArrayFactory.create(
+ { ignorePatterns: IgnorePattern.DefaultPatterns },
+ { name: "DefaultIgnorePattern" }
+ )[0]);
+
+ /*
+ * Load rules `--rulesdir` option as a pseudo plugin.
+ * Use a pseudo plugin to define rules of `--rulesdir`, so we can validate
+ * the rule's options with only information in the config array.
+ */
if (rulePaths && rulePaths.length > 0) {
-
- /*
- * Load rules `--rulesdir` option as a pseudo plugin.
- * Use a pseudo plugin to define rules of `--rulesdir`, so we can
- * validate the rule's options with only information in the config
- * array.
- */
baseConfigArray.push({
name: "--rulesdir",
filePath: "",
@@ -128,6 +138,7 @@ function createBaseConfigArray({
function createCLIConfigArray({
cliConfigData,
configArrayFactory,
+ ignorePath,
specificConfigPath
}) {
const cliConfigArray = configArrayFactory.create(
@@ -135,6 +146,12 @@ function createCLIConfigArray({
{ name: "CLIOptions" }
);
+ cliConfigArray.unshift(
+ ...(ignorePath
+ ? configArrayFactory.loadESLintIgnore(ignorePath)
+ : configArrayFactory.loadDefaultESLintIgnore())
+ );
+
if (specificConfigPath) {
cliConfigArray.unshift(
...configArrayFactory.loadFile(
@@ -178,6 +195,7 @@ class CascadingConfigArrayFactory {
baseConfig: baseConfigData = null,
cliConfig: cliConfigData = null,
cwd = process.cwd(),
+ ignorePath,
resolvePluginsRelativeTo = cwd,
rulePaths = [],
specificConfigPath = null,
@@ -200,6 +218,7 @@ class CascadingConfigArrayFactory {
cliConfigArray: createCLIConfigArray({
cliConfigData,
configArrayFactory,
+ ignorePath,
specificConfigPath
}),
cliConfigData,
@@ -207,6 +226,7 @@ class CascadingConfigArrayFactory {
configCache: new Map(),
cwd,
finalizeCache: new WeakMap(),
+ ignorePath,
rulePaths,
specificConfigPath,
useEslintrc
@@ -229,9 +249,11 @@ class CascadingConfigArrayFactory {
* If `filePath` was not given, it returns the config which contains only
* `baseConfigData` and `cliConfigData`.
* @param {string} [filePath] The file path to a file.
+ * @param {Object} [options] The options.
+ * @param {boolean} [options.ignoreNotFoundError] If `true` then it doesn't throw `ConfigurationNotFoundError`.
* @returns {ConfigArray} The config array of the file.
*/
- getConfigArrayForFile(filePath) {
+ getConfigArrayForFile(filePath, { ignoreNotFoundError = false } = {}) {
const {
baseConfigArray,
cliConfigArray,
@@ -248,7 +270,8 @@ class CascadingConfigArrayFactory {
return this._finalizeConfigArray(
this._loadConfigInAncestors(directoryPath),
- directoryPath
+ directoryPath,
+ ignoreNotFoundError
);
}
@@ -354,10 +377,11 @@ class CascadingConfigArrayFactory {
* Concatenate `--config` and other CLI options.
* @param {ConfigArray} configArray The parent config array.
* @param {string} directoryPath The path to the leaf directory to find config files.
+ * @param {boolean} ignoreNotFoundError If `true` then it doesn't throw `ConfigurationNotFoundError`.
* @returns {ConfigArray} The loaded config.
* @private
*/
- _finalizeConfigArray(configArray, directoryPath) {
+ _finalizeConfigArray(configArray, directoryPath, ignoreNotFoundError) {
const {
cliConfigArray,
configArrayFactory,
@@ -403,7 +427,8 @@ class CascadingConfigArrayFactory {
);
}
- if (useEslintrc && finalConfigArray.length === 0) {
+ // At least one element (the default ignore patterns) exists.
+ if (!ignoreNotFoundError && useEslintrc && finalConfigArray.length <= 1) {
throw new ConfigurationNotFoundError(directoryPath);
}
@@ -45,8 +45,9 @@ const debug = require("debug")("eslint:cascading-config-array-factory");
* @property {Map<string,Plugin>} [additionalPluginPool] The map for additional plugins.
* @property {ConfigData} [baseConfig] The config by `baseConfig` option.
- * @property {ConfigData} [cliConfig] The config by CLI options (`--env`, `--global`, `--parser`, `--parser-options`, `--plugin`, and `--rule`). CLI options overwrite the setting in config files.
+ * @property {ConfigData} [cliConfig] The config by CLI options (`--env`, `--global`, `--ignore-pattern`, `--parser`, `--parser-options`, `--plugin`, and `--rule`). CLI options overwrite the setting in config files.
* @property {string} [cwd] The base directory to start lookup.
diff --git a/tools/node_modules/eslint/lib/cli-engine/cli-engine.js b/tools/node_modules/eslint/lib/cli-engine/cli-engine.js
index 8afd262708..0b1c76bac6 100644
--- a/tools/node_modules/eslint/lib/cli-engine/cli-engine.js
+++ b/tools/node_modules/eslint/lib/cli-engine/cli-engine.js
@@ -25,10 +25,9 @@ const ModuleResolver = require("../shared/relative-module-resolver");
const { Linter } = require("../linter");
const builtInRules = require("../rules");
const { CascadingConfigArrayFactory } = require("./cascading-config-array-factory");
-const { getUsedExtractedConfigs } = require("./config-array");
+const { IgnorePattern, getUsedExtractedConfigs } = require("./config-array");
const { FileEnumerator } = require("./file-enumerator");
const hash = require("./hash");
-const { IgnoredPaths } = require("./ignored-paths");
const LintResultCache = require("./lint-result-cache");
const debug = require("debug")("eslint:cli-engine");
@@ -64,7 +63,7 @@ const validFixTypes = new Set(["problem", "suggestion", "layout"]);
* @property {string[]} globals An array of global variables to declare.
* @property {boolean} ignore False disables use of .eslintignore.
* @property {string} ignorePath The ignore file to use instead of .eslintignore.
* @property {string} ignorePattern A glob pattern of files to ignore.
* @property {boolean} useEslintrc False disables looking for .eslintrc
* @property {string} parser The name of the parser to use.
* @property {ParserOptions} parserOptions An object of parserOption settings to use.
@@ -113,8 +112,8 @@ const validFixTypes = new Set(["problem", "suggestion", "layout"]);
* @property {Map<string, Plugin>} additionalPluginPool The map for additional plugins.
* @property {string} cacheFilePath The path to the cache of lint results.
* @property {CascadingConfigArrayFactory} configArrayFactory The factory of configs.
+ * @property {(filePath: string) => boolean} defaultIgnores The default predicate function to check if a file ignored or not.
* @property {FileEnumerator} fileEnumerator The file enumerator.
- * @property {IgnoredPaths} ignoredPaths The ignored paths.
* @property {ConfigArray[]} lastConfigArrays The list of config arrays that the last `executeOnFiles` or `executeOnText` used.
* @property {LintResultCache|null} lintResultCache The cache of lint results.
* @property {Linter} linter The linter instance which has loaded rules.
@@ -486,13 +485,20 @@ function toBooleanMap(keys, defaultValue, displayName) {
* @returns {ConfigData|null} The created config data.
*/
function createConfigDataFromOptions(options) {
- const { parser, parserOptions, plugins, rules } = options;
+ const {
+ ignorePattern,
+ parser,
+ parserOptions,
+ plugins,
+ rules
+ } = options;
const env = toBooleanMap(options.envs, true, "envs");
const globals = toBooleanMap(options.globals, false, "globals");
if (
env === void 0 &&
globals === void 0 &&
+ (ignorePattern === void 0 || ignorePattern.length === 0) &&
parser === void 0 &&
parserOptions === void 0 &&
plugins === void 0 &&
@@ -500,7 +506,15 @@ function createConfigDataFromOptions(options) {
) {
return null;
}
- return { env, globals, parser, parserOptions, plugins, rules };
+ return {
+ env,
+ globals,
+ ignorePatterns: ignorePattern,
+ parser,
+ parserOptions,
+ plugins,
+ rules
+ };
}
/**
@@ -551,19 +565,18 @@ class CLIEngine {
baseConfig: options.baseConfig || null,
cliConfig: createConfigDataFromOptions(options),
cwd: options.cwd,
+ ignorePath: options.ignorePath,
resolvePluginsRelativeTo: options.resolvePluginsRelativeTo,
rulePaths: options.rulePaths,
specificConfigPath: options.configFile,
useEslintrc: options.useEslintrc
});
- const ignoredPaths = new IgnoredPaths(options);
const fileEnumerator = new FileEnumerator({
configArrayFactory,
cwd: options.cwd,
extensions: options.extensions,
globInputPaths: options.globInputPaths,
- ignore: options.ignore,
- ignoredPaths
+ ignore: options.ignore
});
const lintResultCache =
options.cache ? new LintResultCache(cacheFilePath) : null;
@@ -577,8 +590,8 @@ class CLIEngine {
additionalPluginPool,
cacheFilePath,
configArrayFactory,
+ defaultIgnores: IgnorePattern.createDefaultIgnore(options.cwd),
fileEnumerator,
- ignoredPaths,
lastConfigArrays,
lintResultCache,
linter,
@@ -835,7 +848,6 @@ class CLIEngine {
const {
configArrayFactory,
fileEnumerator,
- ignoredPaths,
lastConfigArrays,
linter,
options: {
@@ -852,7 +864,7 @@ class CLIEngine {
// Clear the last used config arrays.
lastConfigArrays.length = 0;
- if (resolvedFilename && ignoredPaths.contains(resolvedFilename)) {
+ if (resolvedFilename && this.isPathIgnored(resolvedFilename)) {
if (warnIgnored) {
results.push(createIgnoreResult(resolvedFilename, cwd));
}
@@ -926,9 +938,23 @@ class CLIEngine {
* @returns {boolean} Whether or not the given path is ignored.
*/
isPathIgnored(filePath) {
- const { ignoredPaths } = internalSlotsMap.get(this);
+ const {
+ configArrayFactory,
+ defaultIgnores,
+ options: { cwd, ignore }
+ } = internalSlotsMap.get(this);
+ const absolutePath = path.resolve(cwd, filePath);
+
+ if (ignore) {
+ const config = configArrayFactory
+ .getConfigArrayForFile(absolutePath)
+ .extractConfig(absolutePath);
+ const ignores = config.ignores || defaultIgnores;
+
+ return ignores(absolutePath);
+ }
- return ignoredPaths.contains(filePath);
+ return defaultIgnores(absolutePath);
}
/**
@@ -64,7 +63,7 @@ const validFixTypes = new Set(["problem", "suggestion", "layout"]);
* @property {boolean} ignore False disables use of .eslintignore.
* @property {string} ignorePath The ignore file to use instead of .eslintignore.
- * @property {string} ignorePattern A glob pattern of files to ignore.
+ * @property {string|string[]} ignorePattern One or more glob patterns to ignore.
* @property {boolean} useEslintrc False disables looking for .eslintrc
* @property {string} parser The name of the parser to use.